# Convert temperature in fahrenheit or kelvin to degrees celcius
# @example
#       converter = Converter.new
#       args = { unit: 'fahrenheit', value: 1.8 }
#       @range = converter.range_to_celcius(args) / 2.0
#       args[:value] = 21
#       @wanted_value = converter.temp_to_celcius(args)

class Converter
  # If range not in celcius, it will be converted into celcius
  # @param args [Hash]
  # @option args [Numeric] :value the given range
  # @option args [String] :unit the unit of the range

  def range_to_celcius(args)
    tempo = if args[:unit] == 'fahrenheit'
              args[:value] / 1.8
            else
              args[:value]
            end
  end

  # If temperature is not in celcius, it will be converted into celcius
  # @param args [Hash]
  # @option args [Numeric] :value the given temperature
  # @option args [String] :unit the unit of the temperature

  def temp_to_celcius(args)
    tempo = if args[:unit] == 'fahrenheit'
              temp_fahrenheit(args[:value])
            elsif args[:unit] == 'kelvin'
              temp_kelvin(args[:value])
            else
              args[:value]
            end
  end

  # Convert value from fahrenheit to celcius
  # @param value [Numeric] the value that should be converted
  # @return [Numeric] return the temperature in celcius

  def temp_fahrenheit(value)
    (value - 32) / 1.8
  end

  # Convert value from kelvin to celcius
  # @param value [Numeric] the value that should be converted
  # @return [Numeric] return the temperature in celcius

  def temp_kelvin(value)
    value - 273.15
  end
end
