require 'json'
require 'thermostat.rb'
require 'converter.rb'
# Class that uses JSON input to handle the thermostat
# @example
#     settings = JSON.generate({temperature: 20.0, range: 1.0})
#     measurement = JSON.generate({temperature: 20.0})
#     expected_result = JSON.generate({cooling: false, heating: false})
#     thermostat = JSONThermostat.new settings
#     result = thermostat.update measurement
class JSONThermostat
  attr_accessor :wanted_value, :range, :unit

  # Takes in a JSON object and parses the different values.
  # @param [JSON] input JSON file with unit, range and wanted value
  # Uses [converter] method for converter instance.

  def initialize()
    @unit = "celsius"
    @range  = 1.0;
    @wanted_value = 21.0;

  end
  def initialize(testjson)
    parsed = JSON.parse(testjson)
    @unit = parsed['unit']
    args = { unit: unit, value: parsed['range'] }
    @range = converter.range_to_celcius(args) / 2.0
    args[:value] = parsed['temperature']
    @wanted_value = converter.temp_to_celcius(args)
  end

  # Uses the Converter class to make a converter instance that can be used.

  def converter
    @converter ||= Converter.new
  end

  # Uses the Thermostat class to make a thermostat instance to process input.

  def thermo
    message = { wanted_value: wanted_value, range: range }
    @thermo ||= Thermostat.new(message)
  end

  # Takes in JSON object to update the current temperature.
  # Uses thermo instance to update the thermostat.
  # @param [JSON] input JSON file with current value
  # Uses [thermo] method for thermo instance.

  def update(testjson)
    parsed = JSON.parse(testjson)
    args = { unit: parsed['unit'], value: parsed['temperature'] }
    thermo.update_current(converter.temp_to_celcius(args))
    thermo.update_thermo
  end
end
