# Determines if the heating should be turned on
# @example 
#       message = { wanted_value: 21.0, range: 1.0 }
#       thermo = Thermostat.new(message)
#       thermo.update_current(18)
#       thermo.update_thermo
class Thermostat
  attr_accessor :current_value, :wanted_value, :range
  attr_accessor :airco, :heating
  # Initializes the thermostat with wanted value, range and unit
  # @param args [Hash]
  # @option args [Numeric] :wanted_value the wanted value
  # @option args [Numeric] :range the range that the value may defer
  # @option args [String] :unit the unit of the value
  def initialize(args)
    @wanted_value = args[:wanted_value]
    @range = args[:range]
  end

  # Update the range
  def update_range(range)
    @range = range
  end

  # Update the wanted value with given value
  # @param wanted_value [Numeric]
  def update_wanted(wanted_value)
    @wanted_value = wanted_value
  end

  # Update the current value with given value
  # @param current_value [Numeric]
  def update_current(current_value)
    @current_value = current_value
  end

  # Give return if the airco or heater should be turned on
  # @return [String] return visually if airco or heating should be turned on
  def update_thermo
    airco = return_airco
    heating = return_heating
    "{\"cooling\":#{airco},\"heating\":#{heating}}"
  end

  # @return [boolean] return if airco should be turned on
  def return_airco
    current_value > (wanted_value + range)
  end

  # @return [boolean] return if heating should be turned on
  def return_heating
    current_value < (wanted_value - range)
  end
end
